@@ -31,7 +31,7 @@ class Basking:
     """ Class Basking
     """
 
-    def __init__(self, *args, log_level='WARNING', **kwargs):
+    def __init__(self, *args, log_level='WARNING', api_url=None, **kwargs):
         # Setting the logger
         self.log = logging.getLogger(self.__class__.__name__)
         self.log.setLevel(log_level)
@@ -43,7 +43,7 @@ class Basking:
         self.occupancy = Occupancy(basking_obj=self)
         self.location = Location(basking_obj=self)
         self.organization = Organization(basking_obj=self)
-        self.graphql_query = GraphqlQuery(basking_obj=self)
+        self.graphql_query = GraphqlQuery(basking_obj=self, api_url=api_url)
         self.insight = Insight(basking_obj=self)
         self.user = User(basking_obj=self)
         self.utils = Utils(basking_obj=self)
