@@ -17,7 +17,6 @@ from graphqlclient import GraphQLClient
 
 from .constant import BASKING_API_URL
 from .queries import *
-from .utils import deprecated
 
 
 @dataclass
@@ -41,9 +40,9 @@ class GraphqlQuery:
     _ggraphql_client = None
     DATE_FORMAT = '%Y-%m-%dT%H:%M:%S.000Z'
 
-    def __init__(self, basking_obj):
+    def __init__(self, basking_obj, api_url=None):
         self.basking = basking_obj
-        self.basking_api_url = BASKING_API_URL
+        self.basking_api_url = api_url if api_url else BASKING_API_URL
         self.log = logging.getLogger(self.__class__.__name__)
         basking_log_level = logging.getLogger(self.basking.__class__.__name__).level
         self.log.setLevel(basking_log_level)
@@ -111,7 +110,8 @@ class GraphqlQuery:
             self.log.error('API server error', exc_info=True)
 
     @staticmethod
-    def get_building_occupancy_stats_daily_graphql_query(building_id, start_date, end_date) -> (str, dict):
+    def get_building_occupancy_stats_daily_graphql_query(building_id, start_date, end_date, capacity_type=None) -> (
+            str, dict):
         """graphql query for get_building_occupancy_stats_daily function
         :return: graphql query, variables
         """
@@ -120,8 +120,13 @@ class GraphqlQuery:
             'from': start_date.strftime(GraphqlQuery.DATE_FORMAT),
             'to': end_date.strftime(GraphqlQuery.DATE_FORMAT),
         }
+        if capacity_type:
+            variables['capacity_type'] = capacity_type
+            query = GET_LOCATION_STATS_DAILY
+        else:
+            query = '\n'.join(filter(lambda x: 'capacityType' not in x, GET_LOCATION_STATS_DAILY.splitlines()))
 
-        return GET_LOCATION_STATS_DAILY, variables
+        return query, variables
 
     @staticmethod
     def get_building_graphql_query(building_id):
@@ -143,6 +148,7 @@ class GraphqlQuery:
             building_id,
             start_date: date,
             end_date: date,
+            capacity_type=None
     ) -> (str, dict):
         """graphql query and variables for _get_building_occupancy_hourly_pagination function
         """
@@ -153,7 +159,13 @@ class GraphqlQuery:
             "floorAreaId": 0,
         }
 
-        return GET_LOCATION_OCCUPANCY_HOURLY, variables
+        if capacity_type:
+            variables['capacity_type'] = capacity_type
+            query = GET_LOCATION_OCCUPANCY_HOURLY
+        else:
+            query = '\n'.join(filter(lambda x: 'capacityType' not in x, GET_LOCATION_OCCUPANCY_HOURLY.splitlines()))
+
+        return query, variables
 
     @staticmethod
     def get_floor_heatmap_kpi_graphql_query(
@@ -228,9 +240,9 @@ class GraphqlQuery:
         return GET_USER_LOCATIONS
 
     @staticmethod
-    def get_location_duration_of_visits_graphql_query(building_id, start_date, end_date) -> (str, dict):
+    def get_location_duration_of_visits_graphql_query(building_id, start_date, end_date, capacity_type=None) -> (
+    str, dict):
         """graphql query for get_duration_of_visits_histogram function
-
         """
 
         variables = {
@@ -238,11 +250,17 @@ class GraphqlQuery:
             'from': start_date.strftime(GraphqlQuery.DATE_FORMAT),
             'to': end_date.strftime(GraphqlQuery.DATE_FORMAT),
         }
+        if capacity_type:
+            variables['capacity_type'] = capacity_type
+            query = GET_LOCATION_VISIT_DURATION
+        else:
+            query = '\n'.join(filter(lambda x: 'capacityType' not in x, GET_LOCATION_VISIT_DURATION.splitlines()))
 
-        return GET_LOCATION_VISIT_DURATION, variables
+        return query, variables
 
     @staticmethod
-    def get_location_frequency_of_visits_graphql_query(building_id, start_date, end_date) -> (str, dict):
+    def get_location_frequency_of_visits_graphql_query(building_id, start_date, end_date, capacity_type=None) -> (
+    str, dict):
         """graphql query for get_frequency_of_visits_histogram function
         """
         variables = {
@@ -250,7 +268,13 @@ class GraphqlQuery:
             'from': start_date.strftime(GraphqlQuery.DATE_FORMAT),
             'to': end_date.strftime(GraphqlQuery.DATE_FORMAT),
         }
-        return GET_LOCATION_VISIT_FREQ, variables
+        if capacity_type:
+            variables['capacity_type'] = capacity_type
+            query = GET_LOCATION_VISIT_FREQ
+        else:
+            query = '\n'.join(filter(lambda x: 'capacityType' not in x, GET_LOCATION_VISIT_FREQ.splitlines()))
+
+        return query, variables
 
     @staticmethod
     def get_hoteling_by_org_graphql_query(organizationid: int, start_date: date, end_date: date) -> (str, dict):
@@ -293,8 +317,8 @@ class GraphqlQuery:
     def get_location_popular_days_of_visits_graphql_query(
             building_id,
             start_date,
-            end_date
-
+            end_date,
+            capacity_type=None,
     ) -> (str, dict):
         """graphql query for get_location_popular_days_of_visits
 
@@ -305,7 +329,13 @@ class GraphqlQuery:
             'from': start_date.strftime(GraphqlQuery.DATE_FORMAT),
             'to': end_date.strftime(GraphqlQuery.DATE_FORMAT),
         }
-        return GET_LOCATION_POPULAR_VISIT_DAYS, variables
+        if capacity_type:
+            variables['capacity_type'] = capacity_type
+            query = GET_LOCATION_POPULAR_VISIT_DAYS
+        else:
+            query = '\n'.join(filter(lambda x: 'capacityType' not in x, GET_LOCATION_POPULAR_VISIT_DAYS.splitlines()))
+
+        return query, variables
 
     @staticmethod
     def get_organization_frequency_of_visits_graphql_query(organization_id, start_date, end_date) -> (str, dict):
