@@ -8,13 +8,15 @@ import json
 import logging
 import os
 from datetime import datetime, timedelta, date, time
-from typing import Tuple, Iterator, Union, List
+from typing import Tuple, Iterator, Union, List, Literal, Optional
 
 import pandas
 import pandas as pd
 
 SQM_TO_SQF_RATE = 10.7639
 
+CapacityType = Literal['workstations', 'total_seats']
+
 
 class Occupancy:
     """
@@ -34,7 +36,9 @@ class Occupancy:
             self, building_id,
             start_date: date,
             end_date: date,
-            pandify=False
+            pandify=False,
+            *,
+            capacity_type: CapacityType = None,
     ) -> Union[pandas.DataFrame, List[dict]]:
         """
         Returns daily statistical occupancy data for a building between the given time frames.
@@ -52,7 +56,8 @@ class Occupancy:
                     *self.basking.graphql_query.get_building_occupancy_stats_daily_graphql_query(
                         building_id,
                         start_date,
-                        end_date
+                        end_date,
+                        capacity_type,
                     )
                 )
                 data += json.loads(result)['data']['location']['occupancy']['daily']
@@ -106,7 +111,9 @@ class Occupancy:
             ap_floor_id: int = None,
             floor_area_id: int = None,
             ap_id=0,
-            pandify=True
+            pandify=True,
+            *,
+            capacity_type: CapacityType = None,
     ) -> Union[pandas.DataFrame, List[dict]]:
         """
         This function returns the hourly occupancy data for the specified range aggregated in 3 levels.
@@ -133,7 +140,8 @@ class Occupancy:
                     building_id,
                     ap_floor_id,
                     floor_area_id,
-                    ap_id
+                    ap_id,
+                    capacity_type=capacity_type,
                 )
                 if 'message' in data:
                     self.basking.api_timeout_handler(data)
@@ -173,7 +181,9 @@ class Occupancy:
             building_id: str,
             ap_floor_id: int,
             floor_area_id: int,
-            ap_id: int
+            ap_id: int,
+            *,
+            capacity_type: CapacityType = None
     ) -> dict:
         """
         Internal method used to paginate long queries of hourly data.
@@ -183,7 +193,8 @@ class Occupancy:
         query, variables = self.basking.graphql_query.get_building_occupancy_hourly_pagination_graphql_query(
             building_id,
             start_date,
-            end_date
+            end_date,
+            capacity_type,
         )
 
         if ap_floor_id:
@@ -209,7 +220,9 @@ class Occupancy:
             self,
             building_id: str,
             start_date: date,
-            end_date: date
+            end_date: date,
+            *,
+            capacity_type: CapacityType = None,
     ) -> pandas.DataFrame:
         """
         get_building_occupancy_hourly_by_floor allows for batch processing floor data.
@@ -228,7 +241,7 @@ class Occupancy:
         )
         try:
             meraki_floors = self.basking.location.get_building(
-                building_id)['data']['getBuilding']['merakiApFloors']
+                building_id)['data']['getBuilding']['floors']
         except TypeError:
             self.log.info('got no data in get_building_occupancy_hourly_by_floor')
             return pd.DataFrame()  # creates a new dataframe that's empty
@@ -243,12 +256,13 @@ class Occupancy:
                 start_date=start_date,
                 end_date=end_date,
                 ap_floor_id=this_meraki_ap_floor_id,
-                pandify=True
+                pandify=True,
+                capacity_type=capacity_type,
             )
 
             if isinstance(df_, pd.DataFrame):
                 df_['floor_ap_id'] = this_meraki_ap_floor_id
-                df_['floorName'] = this_meraki_ap_floor['floorName']
+                df_['floorName'] = this_meraki_ap_floor['name']
                 tmp_array_of_df.append(df_)
         if len(tmp_array_of_df):
             df = pd.concat(tmp_array_of_df)
@@ -261,6 +275,8 @@ class Occupancy:
             building_id: str,
             start_date: date = None,
             end_date: date = None,
+            *,
+            capacity_type: CapacityType = None,
     ) -> pandas.DataFrame:
         """
         get_building_occupancy_hourly_by_floor_area allows for batch processing floor area data.
@@ -289,7 +305,8 @@ class Occupancy:
                     start_date=start_date,
                     end_date=end_date,
                     floor_area_id=this_floor_area_id,
-                    pandify=True
+                    pandify=True,
+                    capacity_type=capacity_type,
                 )
                 if isinstance(df_, pd.DataFrame):
                     df_['floor_area_id'] = this_floor_area_id
@@ -351,7 +368,9 @@ class Occupancy:
             building_id: str,
             start_date: date,
             end_date: date,
-            pandify=True
+            pandify=True,
+            *,
+            capacity_type: CapacityType = None,
     ) -> Union[pandas.DataFrame, List[dict]]:
         """
         Returns the histogram of the duration of visits between 2 dates at building level.
@@ -364,6 +383,7 @@ class Occupancy:
             building_id,
             start_date,
             end_date,
+            capacity_type,
         )
 
         result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
@@ -399,7 +419,9 @@ class Occupancy:
             building_id: str,
             start_date: date,
             end_date: date,
-            pandify=None
+            pandify=None,
+            *,
+            capacity_type: CapacityType = None,
     ) -> Union[pandas.DataFrame, List[dict]]:
 
         """
@@ -414,6 +436,7 @@ class Occupancy:
             building_id,
             start_date,
             end_date,
+            capacity_type,
         )
 
         result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
@@ -441,7 +464,9 @@ class Occupancy:
             building_id: str,
             start_date: date,
             end_date: date,
-    ):
+            *,
+            capacity_type: CapacityType = None,
+    ) -> Optional[int]:
         """
         Returns the density of the office in RSM at peak between the time period defined.
 
@@ -473,7 +498,8 @@ class Occupancy:
                 building_id=str(building_id),
                 start_date=start_date,
                 end_date=end_date,
-                pandify=True
+                pandify=True,
+                capacity_type=capacity_type,
             )
         except (AttributeError, TypeError):
             self.log.error('no data')
@@ -487,7 +513,9 @@ class Occupancy:
     def get_density_for_building_last_days(
             self,
             building_id: str,
-            days=7
+            days=7,
+            *,
+            capacity_type: CapacityType = None,
     ):
         """
         Returns the density of an office in RSM at peak for the last 7 days from now.
@@ -498,7 +526,8 @@ class Occupancy:
             self.get_density_for_building(
                 building_id=building_id,
                 start_date=start_date_obj,
-                end_date=end_date_obj
+                end_date=end_date_obj,
+                capacity_type=capacity_type,
             )
         )
 
@@ -507,7 +536,9 @@ class Occupancy:
             building_id: str,
             start_date: date,
             end_date: date,
-            pandify=None
+            pandify=None,
+            *,
+            capacity_type: CapacityType = None,
     ):
         """
         Returns the popular days of visits for a location between the specified dates.
@@ -527,6 +558,7 @@ class Occupancy:
                 building_id,
                 start_date,
                 end_date,
+                capacity_type,
             )
             result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
             data = json.loads(result)
