@@ -260,15 +260,18 @@ class Organization:
                 )
 
                 daily_peak_data = []
-                df_data = daily_data.query('date')
                 for date_d in daily_data.index:
+                    df_data = daily_data.query('date')
                     week_day = calendar.day_name[date_d.weekday()]
                     if week_day in days:
                         daily_peak_data.append(df_data.loc[date_d]['occupancy_daily_peak'])
-                avg_of_daily_peak = sum(daily_peak_data) / len(daily_peak_data)
-                avg_of_daily_peak_pct = int((avg_of_daily_peak * 100) / location['capacity'])
-                max_val = max(daily_peak_data)
-                max_val_pct = int((max_val * 100) / location['capacity'])
+                if len(daily_peak_data) != 0 and location['capacity'] > 0:
+                    avg_of_daily_peak = sum(daily_peak_data) / len(daily_peak_data)
+                    avg_of_daily_peak_pct = int((avg_of_daily_peak * 100) / location['capacity'])
+                    max_val = max(daily_peak_data)
+                    max_val_pct = int((max_val * 100) / location['capacity'])
+                else:
+                    avg_of_daily_peak, avg_of_daily_peak_pct, max_val, max_val_pct = 0, 0, 0, 0
 
                 main_dict.update({building_id: {"building_name": location['name']}})
                 if ranking_metric == "average_daily_peak_pct":
