@@ -26,18 +26,19 @@ GET_ORG_VISIT_FREQ = """
         }
         """
 
-# TODO: `lastCount` is deprecated and will be removed from the API during 02/2023
 GET_LOCATION_STATS_DAILY = """
                     query get_building_occupancy_stats_daily(
                         $id: ID!,
                         $from: DateTime!,
                         $to: DateTime!
+                        $capacityType: String
                     ) {
                         location(id: $id) {
                             occupancy{
                                 daily(
                                     from: $from,
                                     to: $to
+                                    capacityType: $capacityType
                                 ) {
                                     date, 
                                     peakCount,
@@ -59,6 +60,9 @@ GET_LOCATION = """
                             workingDays,
                             name,
                             capacity,
+                            currentAdjCapacityAbs,
+                            workstationsCapacity,
+                            totalSeatsCapacity,
                             numberOfDesks,
                             address,
                             timeZone,
@@ -66,8 +70,7 @@ GET_LOCATION = """
                             lng,
                             organizationId,
                             organization{id, name},
-                            merakiApFloors{id, apFloors, floorName, createdAt},
-                            floors{id, buildingId, number, name, capacity, sqm, floorplanURL, rotation, neCorner, swCorner},
+                            floors{id, vendorFloorId, buildingId, createdAt, number, name, capacity, workstationsCapacity, totalSeatsCapacity, sqm, floorplanURL, rotation, neCorner, swCorner},
                             rentPriceSQM,
                             currency,
                             area,
@@ -90,6 +93,7 @@ GET_LOCATION_OCCUPANCY_HOURLY = """
                         $to: DateTime!,
                         $floorId: String,
                         $floorAreaId: Int,
+                        $capacityType: String
                     ) {
                         location(id: $id) {
                             occupancy{
@@ -98,6 +102,7 @@ GET_LOCATION_OCCUPANCY_HOURLY = """
                                     to: $to,
                                     floorId: $floorId,
                                     floorAreaId: $floorAreaId,
+                                    capacityType: $capacityType
                                 ) {
                                     hour, 
                                     occupancy: uniqueCount,
@@ -190,13 +195,15 @@ GET_LOCATION_VISIT_DURATION = """
                     query duration(
                         $id: ID!,
                         $from: DateTime!,
-                        $to: DateTime!
+                        $to: DateTime!,
+                        $capacityType: String
                     ) {
                         location(id: $id) {
                             occupancy{
                                 duration(
                                     from: $from, 
-                                    to: $to
+                                    to: $to,
+                                    capacityType: $capacityType
                                 ) {
                                     visitDuration: hoursCount, 
                                     visitsCount: clientsCount,
@@ -212,12 +219,14 @@ GET_LOCATION_VISIT_FREQ = """
                         $id: ID!,
                         $from: DateTime!,
                         $to: DateTime!
+                        $capacityType: String
                     ) {
                         location(id: $id) {
                             occupancy{
                                 daysPerWeek(
                                     from: $from, 
-                                    to: $to
+                                    to: $to,
+                                    capacityType: $capacityType
                                 ) {
                                     visitFrequency: daysPerWeek, 
                                     visitsCount: clientsCount,
@@ -273,13 +282,15 @@ GET_LOCATION_POPULAR_VISIT_DAYS = """
              query popularDays(
                 $id: ID!,
                 $from: DateTime!,
-                $to: DateTime!
+                $to: DateTime!,
+                $capacityType: String
             ) {
                 location(id: $id) {
                     occupancy{
                         popularDaysOfVisit(
                             from: $from, 
-                            to: $to
+                            to: $to,
+                            capacityType: $capacityType
                         ) {
                             visitWeekday: dayOfWeek, 
                             visitsCount: clientsCount,
@@ -356,7 +367,9 @@ GET_ORG_LOCATIONS = """
                   hasMeraki,
                   workingDays,
                   operationStartTime,
-                  operationEndTime
+                  operationEndTime,
+                  totalSeatsCapacity,
+                  workstationsCapacity
                 }
               }
         """
